@@ -14,11 +14,28 @@ window.datetime_elements = datetime_element_list
 
 $('.init-datetime').each(function(){
     let element = $(this).get(0)
-    let td = new TempusDominus(element, {
-        display: {
-            sideBySide: true
-        }
-    });
+    let td
+    let type = $(this).closest("[setting-type]").attr("setting-type")
+    switch(type){
+        case "datetime":
+            td = new TempusDominus(element, {
+                display: {
+                    sideBySide: true
+                }, 
+            });
+            break
+        case "date":
+            td = new TempusDominus(element, {
+                display: {
+                    components: {
+                        clock: false
+                    }
+                },
+            });
+            break
+    }
+
+
     datetime_element_list[element] = td
 }).get()
 
